Module abi

Module abi 

Formal audio plugin ABI records shared by the host and test fixtures.

Structs

WasmAudioManifest
Flat manifest written by a wasm audio guest to linear memory.

Constants

EXPORT_MANIFEST_PTR
Required wasm export returning the audio manifest pointer.
EXPORT_PREPARE
Required wasm export preparing the plugin for a sample rate and block size.
EXPORT_PROCESS
Required wasm export processing one host-provided audio block.
EXPORT_RESET
Required wasm export resetting plugin state.
IMPORT_AUDIO_READ
Required wasm import reading one input sample.
IMPORT_AUDIO_WRITE
Required wasm import writing one output sample.
IMPORT_FRAME_COUNT
Required wasm import returning the current host block frame count.
IMPORT_MODULE
Required wasm import module for host callbacks.
IMPORT_PARAM_GET
Required wasm import reading one host parameter value.