WebAssembly audio plugin host for SIM audio graph processors.
The default build contains the manifest data model. Enabling the
wasm-plugin feature adds a wasmtime-backed WasmPluginProcessor that
implements sim_lib_plugin_core::PluginInstance.
Re-exports
pub use limits::WasmResourceLimits;pub use loader::load_wasm_plugin;pub use processor::WasmPluginProcessor;pub use router::PluginRouter;pub use router::PluginRouterBuilder;pub use router::RoutedPlugin;
Modules
- abi
- Formal audio plugin ABI records shared by the host and test fixtures.
- limits
- Resource-limit policy for WebAssembly audio plugins.
- loader
- Capability-checked WebAssembly plugin loading.
- native_
fallback - Capability-checked native plugin fallback loading.
- processor
- Wasmtime-backed audio plugin processor.
- router
- Format-dispatching plugin loader.
Structs
- Wasm
Audio Manifest - Flat manifest written by a wasm audio guest to linear memory.