Formal audio plugin ABI records shared by the host and test fixtures.
Structs
- Wasm
Audio Manifest - Flat manifest written by a wasm audio guest to linear memory.
Constants
- EXPORT_
MANIFEST_ PTR - Required wasm export returning the audio manifest pointer.
- EXPORT_
PREPARE - Required wasm export preparing the plugin for a sample rate and block size.
- EXPORT_
PROCESS - Required wasm export processing one host-provided audio block.
- EXPORT_
RESET - Required wasm export resetting plugin state.
- IMPORT_
AUDIO_ READ - Required wasm import reading one input sample.
- IMPORT_
AUDIO_ WRITE - Required wasm import writing one output sample.
- IMPORT_
FRAME_ COUNT - Required wasm import returning the current host block frame count.
- IMPORT_
MODULE - Required wasm import module for host callbacks.
- IMPORT_
PARAM_ GET - Required wasm import reading one host parameter value.