pub struct WasmPluginProcessor { /* private fields */ }Expand description
WebAssembly-backed plugin instance exposed through the shared plugin API.
Implementations
Sourceimpl WasmPluginProcessor
impl WasmPluginProcessor
Sourcepub fn descriptor(&self) -> &PluginDescriptor
pub fn descriptor(&self) -> &PluginDescriptor
Returns this plugin’s descriptor.
Sourceimpl WasmPluginProcessor
impl WasmPluginProcessor
Sourcepub fn from_bytes(wasm: &[u8]) -> Result<Self>
pub fn from_bytes(wasm: &[u8]) -> Result<Self>
Reports that the wasm runtime feature is disabled.
Errors
Always returns an eval error because no runtime is available.
Sourcepub fn from_bytes_with_limits(
_wasm: &[u8],
_limits: WasmResourceLimits,
) -> Result<Self>
pub fn from_bytes_with_limits( _wasm: &[u8], _limits: WasmResourceLimits, ) -> Result<Self>
Reports that the wasm runtime feature is disabled.
Errors
Always returns an eval error because no runtime is available.